@@ -342,7 +342,7 @@ class Server(signals.Provider):
 			self.crypto_context.set_options(SSL.OP_NO_SSLv2)
 			self.crypto_context.set_options(SSL.OP_NO_SSLv3)
 			self.crypto_context.set_verify(SSL.VERIFY_PEER, self.__verify_cert_cb)
-			dir = '/etc/univention/ssl/%(hostname)s.%(dirname)s' % ucr
+			dir = '/etc/univention/ssl/%(hostname)s.%(domainname)s' % ucr
 			try:
 				self.crypto_context.use_privatekey_file(os.path.join(dir, 'private.key'))
 				self.crypto_context.use_certificate_file(os.path.join(dir, 'cert.pem'))
